==> haskell-th-lift-instances-0.1.18-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-lift-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-lift-instances
version:              0.1.18
visibility:           public
id:                   th-lift-instances-0.1.18-63gR2Y9GDX91y6z3ZZCAiY
key:                  th-lift-instances-0.1.18-63gR2Y9GDX91y6z3ZZCAiY
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2020 Benno Fünfstück
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Benno Fünfstück
stability:            experimental
homepage:             http://github.com/bennofs/th-lift-instances/
synopsis:             Lift instances for template-haskell for common data types.
description:
    Most data types in the haskell platform do not have Lift instances.
    This package provides orphan instances for containers, text, bytestring and vector.
    It also provides compat instances for older versions of @template-haskell@

    Note that <https://hackage.haskell.org/package/th-lift th-lift> package provides
    Template Haskell based derivation of @Lift@ instances (when you cannot use @DeriveLift@ extension),
    and <https://hackage.haskell.org/package/th-orphans th-orphans> package provides instances for TH datatypes.

category:             Template Haskell
abi:                  9c92a68d60694c3a01fca9887c5a68a5
exposed:              True
exposed-modules:      Instances.TH.Lift
import-dirs:          /usr/lib/ghc-8.10.4/site-local/th-lift-instances-0.1.18
library-dirs:         /usr/lib/ghc-8.10.4/site-local/th-lift-instances-0.1.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/th-lift-instances-0.1.18
hs-libraries:         HSth-lift-instances-0.1.18-63gR2Y9GDX91y6z3ZZCAiY
depends:
    base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    template-haskell-2.16.0.0 text-1.2.4.1
    th-lift-0.8.2-7d37mrJ37yC1VcDgqjDphG transformers-0.5.6.2
    vector-0.12.3.0-J0643wU0pjQ5NoWe4yzXTz

haddock-interfaces:
    /usr/share/doc/haskell-th-lift-instances/html/th-lift-instances.haddock

haddock-html:         /usr/share/doc/haskell-th-lift-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-lift-instances-0.1.18-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-lift-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-lift-instances
version:              0.1.18
visibility:           public
id:                   th-lift-instances-0.1.18-ITLwgpHfp81BhBZMG5OkBV
key:                  th-lift-instances-0.1.18-ITLwgpHfp81BhBZMG5OkBV
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2020 Benno Fünfstück
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Benno Fünfstück
stability:            experimental
homepage:             http://github.com/bennofs/th-lift-instances/
synopsis:             Lift instances for template-haskell for common data types.
description:
    Most data types in the haskell platform do not have Lift instances.
    This package provides orphan instances for containers, text, bytestring and vector.
    It also provides compat instances for older versions of @template-haskell@

    Note that <https://hackage.haskell.org/package/th-lift th-lift> package provides
    Template Haskell based derivation of @Lift@ instances (when you cannot use @DeriveLift@ extension),
    and <https://hackage.haskell.org/package/th-orphans th-orphans> package provides instances for TH datatypes.

category:             Template Haskell
abi:                  db7fe52b405a9360c0312b317c59e393
exposed:              True
exposed-modules:      Instances.TH.Lift
import-dirs:          /usr/lib/ghc-8.10.5/site-local/th-lift-instances-0.1.18
library-dirs:         /usr/lib/ghc-8.10.5/site-local/th-lift-instances-0.1.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/th-lift-instances-0.1.18
hs-libraries:         HSth-lift-instances-0.1.18-ITLwgpHfp81BhBZMG5OkBV
depends:
    base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1
    template-haskell-2.16.0.0 text-1.2.4.1
    th-lift-0.8.2-A94jWiBJfaQF1v2Vq9YgsH transformers-0.5.6.2
    vector-0.12.3.0-EcRb4NXFUGH91vV3xG3jJs

haddock-interfaces:
    /usr/share/doc/haskell-th-lift-instances/html/th-lift-instances.haddock

haddock-html:         /usr/share/doc/haskell-th-lift-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
